UStorage
========

Unified Storage Interface for Python.
Copied and decoupled from [Flask-FS](https://github.com/noirbizarre/flask-fs) for working anywhere.

Thanks to [Flask-FS](https://github.com/noirbizarre/flask-fs)

See also [django-storages](https://github.com/jschneier/django-storages)
